#!C:\b\abs_98c4fxx40h\croot\gdal-split_1673969693735\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','gdal_sieve.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'gdal_sieve.py')
